.. Meal Generator documentation master file.

###################################
Welcome to Meal Generator's Docs!
###################################

This documentation provides a detailed reference for the ``meal_generator`` package, including all modules, classes, and functions.

.. toctree::
   :maxdepth: 2
   :caption: API Reference:

   generator
   meal
   meal_component
   nutrient_profile
   
******************
Indices and Tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`